==> rocketmq-client-3.1.8-sources.jar: com/alibaba/rocketmq/client/impl/consumer/ConsumeMessageService.java <==
/**
 * Copyright (C) 2010-2013 Alibaba Group Holding Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.rocketmq.client.impl.consumer;

import java.util.List;

import com.alibaba.rocketmq.common.message.MessageExt;
import com.alibaba.rocketmq.common.message.MessageQueue;
import com.alibaba.rocketmq.common.protocol.body.ConsumeMessageDirectlyResult;


/**
 * 消费消息服务，公共接口
 * 
 * @author shijia.wxr<vintage.wang@gmail.com>
 * @since 2013-7-24
 */
public interface ConsumeMessageService {
    public void start();


    public void shutdown();


    public void updateCorePoolSize(int corePoolSize);


    public void incCorePoolSize();


    public void decCorePoolSize();


    public int getCorePoolSize();


    public ConsumeMessageDirectlyResult consumeMessageDirectly(final MessageExt msg, final String brokerName);


    public void submitConsumeRequest(//
            final List<MessageExt> msgs, //
            final ProcessQueue processQueue, //
            final MessageQueue messageQueue, //
            final boolean dispathToConsume);
}

==> rocketmq-client-3.4.6-sources.jar: com/alibaba/rocketmq/client/impl/consumer/ConsumeMessageService.java <==
/**
 * Copyright (C) 2010-2013 Alibaba Group Holding Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.alibaba.rocketmq.client.impl.consumer;

import java.util.List;

import com.alibaba.rocketmq.common.message.MessageExt;
import com.alibaba.rocketmq.common.message.MessageQueue;
import com.alibaba.rocketmq.common.protocol.body.ConsumeMessageDirectlyResult;


/**
 * @author shijia.wxr<vintage.wang@gmail.com>
 * @since 2013-7-24
 */
public interface ConsumeMessageService {
    void start();


    void shutdown();


    void updateCorePoolSize(int corePoolSize);


    void incCorePoolSize();


    void decCorePoolSize();


    int getCorePoolSize();


    ConsumeMessageDirectlyResult consumeMessageDirectly(final MessageExt msg, final String brokerName);


    void submitConsumeRequest(//
                              final List<MessageExt> msgs, //
                              final ProcessQueue processQueue, //
                              final MessageQueue messageQueue, //
                              final boolean dispathToConsume);
}
